.. rabbitChat documentation master file, created by
   sphinx-quickstart on Thu May 19 01:20:05 2016.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to rabbitChat's documentation!
======================================


A Chat-Server/Chat-System based on AMQP protocol(RabbitMQ Message Broker)

**Home Page :** https://pypi.python.org/pypi/rabbitChat


Details
-------

:Author: Anirban Roy Das         
:Email: anirban.nick@gmail.com
:Copyright(C): 2016, Anirban Roy Das <anirban.nick@gmail.com>

Check ``rabbitChat/LICENSE`` file for full Copyright notice.



Documentation:
--------------

.. toctree::
   :maxdepth: 2

   overview
   features
   installation
   usage
   api
   references




Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

